# DISHA

## Data Integrated solutions for healthy futures with AI
DISHA is a collaborative platform for health data integration and analysis.
Currently, DISHA is in intial phases of it is development for data integration platform in the health sector.
We have weather forecasting and LSTM based malaria forecasting models for the malaria. Given the 4 weeks for data in advance
we can predict the next 4 weeks' malaria data. Using weather forecasting tool, we can forecast weather upto 7 days in advance for any coordinate. 

## Installation
```pip install DISHA``` 

## License

© 2022 IMACS

This repository is licensed under the Apache License, Version 2.0, 2004. See LICENSE for details.    